# nx_migrate Package

## installation
```
pip install nx-migrate
```

## Usage
- Example on Windows
```
nx-migrate -u "C:\my-monorepo"
```

- Example on Linux/macOS
```
nx-migrate -u "/Users/me/my-monorepo"
```

